@@ -6,6 +6,7 @@ use crate::{
 };
 use core::{alloc::Layout, ptr};
 use ptr_meta::Pointee;
+use std::alloc;
 use std::ffi::{CStr, CString};
 
 // CStr
@@ -110,7 +111,7 @@ where
         unsafe {
             let data_address = self
                 .as_c_str()
-                .deserialize_unsized(deserializer, |layout| alloc::alloc::alloc(layout))?;
+                .deserialize_unsized(deserializer, |layout| alloc::alloc(layout))?;
             let metadata = self.as_c_str().deserialize_metadata(deserializer)?;
             let ptr = ptr_meta::from_raw_parts_mut(data_address, metadata);
             Ok(Box::<CStr>::from_raw(ptr).into())
